/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","az",{abort:"Serverə yükləmə istifadəçi tərəfindən dayandırılıb",doneOne:"Fayl müvəffəqiyyətlə yüklənib",doneMany:"%1 fayllar müvəffəqiyyətlə yüklənib",uploadOne:"Faylın yüklənməsi ({percentage}%)",uploadMany:"Faylların yüklənməsi,  {max}-dan {current} hazır ({percentage}%)..."});