/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","hu",{loadError:"Hiba történt a fájl olvasása közben.",networkError:"Hálózati hiba történt a fájl feltöltése közben.",httpError404:"HTTP hiba történt a fájl feltöltése alatt (404: A fájl nem található).",httpError403:"HTTP hiba történt a fájl feltöltése alatt (403: Tiltott).",httpError:"HTTP hiba történt a fájl feltöltése alatt (hiba státusz: %1).",noUrlError:"Feltöltési URL nincs megadva.",responseError:"Helytelen szerver válasz."});