/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","lv",{title:"UI krāsas izvēle",options:"Color Options",highlight:"Highlight",selected:"Selected Color",predefined:"Predefinēti krāsu komplekti",config:"Ielīmējiet šo rindu jūsu config.js failā"});