/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","ja",{loadError:"ファイルの読み込み中にエラーが発生しました。",networkError:"ファイルのアップロード中にネットワークエラーが発生しました。",httpError404:"ファイルのアップロード中にHTTPエラーが発生しました。(404: File not found)",httpError403:"ファイルのアップロード中にHTTPエラーが発生しました。(403: Forbidden)",httpError:"ファイルのアップロード中にHTTPエラーが発生しました。(error status: %1)",noUrlError:"アップロードURLが定義されていません。",responseError:"サーバーの応答が不正です。"});