/*
Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'image2', 'id', {
	alt: 'Teks alternatif',
	btnUpload: 'Kirim ke Server',
	captioned: 'Captioned image', // MISSING
	captionPlaceholder: 'Caption', // MISSING
	infoTab: 'Info Gambar',
	lockRatio: 'Lock Ratio', // MISSING
	menu: 'Image Properties', // MISSING
	pathName: 'image', // MISSING
	pathNameCaption: 'caption', // MISSING
	resetSize: 'Atur Ulang Ukuran',
	resizer: 'Click and drag to resize', // MISSING
	title: 'Image Properties', // MISSING
	uploadTab: 'Unggah',
	urlMissing: 'Image source URL is missing.', // MISSING
	altMissing: 'Alternative text is missing.' // MISSING
} );
