/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","el",{abort:"Αποστολή ακυρώθηκε απο χρήστη.",doneOne:"Αρχείο εστάλη επιτυχώς.",doneMany:"Επιτυχής αποστολή %1 αρχείων.",uploadOne:"Αποστολή αρχείου ({percentage}%)…",uploadMany:"Αποστολή αρχείων, {current} από {max} ολοκληρωμένα ({percentage}%)…"});