/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","ca",{abort:"Pujada cancel·lada per l'usuari.",doneOne:"Fitxer pujat correctament.",doneMany:"%1 fitxers pujats correctament.",uploadOne:"Pujant fitxer ({percentage}%)...",uploadMany:"Pujant fitxers, {current} de {max} finalitzats ({percentage}%)..."});