/*
 Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("devtools","de-ch",{title:"Elementinformation",dialogName:"Dialogfenstername",tabName:"Reitername",elementId:"Elementkennung",elementType:"Elementtyp"});